/*
 * XetPan: a libEtPan! based Mail User Agent
 * Copyright (C) 2002-2003 Melvin Hadasht
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef CNTREE_H
#define CNTREE_H

#include <clist.h>

typedef struct cntree_s cntree;

struct cntree_s {
  void *data;
  clist *children;
  cntree *parent;
};

cntree *
cntree_new(void);

cntree *
cntree_new_with_data(void *data);

void
cntree_free(cntree *ntree, void (*free_callback)(cntree *atree, void *adata),
	    void *data);

clist *
cntree_get_children(cntree *ntree);

void
cntree_set_children(cntree *ntree, clist *children);

int
cntree_append_child(cntree *parent, cntree *child);

int
cntree_prepend_child(cntree *parent, cntree *child);

int
cntree_remove_child(cntree* parent, cntree *child);

void
cntree_set_data(cntree *ntree, void *data);

void *
cntree_get_data(cntree *ntree);

int
cntree_get_children_count(cntree *ntree);

int
cntree_for_each(cntree *ntree, int (*callback)(cntree *atree, void *adata), 
		void *data);

int
cntree_for_each_child(cntree *ntree, int (*callback)(cntree *atree, void *data),
		      void *data);

cntree *
cntree_get_root(cntree *ntree);

cntree *
cntree_find_child_with_data(cntree *parent, void *data);

#endif




  
