/*
 * XetPan: a libEtPan! based Mail User Agent
 * Copyright (C) 2002-2003 Melvin Hadasht
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef MAILBOX_H
#define MAILBOX_H

#include <clist.h>

#include "folder-types.h"
#include "mailbox-types.h"
#include "server.h"
#include "manager.h"

/*! Mailbox or mail source.
 *  A mail source (mailbox) is defined by its type (POP3, IMAP, NNTP, MBOX or
 *  MH) and a name.
 */

struct XePMailbox_s
{
  char *id;              /**< Unique identifier. FIXME: an integer?  */
  char *name;            /**< Mailbox name, chosen by the user.      */
  long uid;
  XePMailboxType type;   /**< Type (IMAP, MH, MBOX, NNTP, POP3).     */
  XePServer *server;

  char *inbox_ref;
  char *draft_ref;
  char *queue_ref;
  char *sent_ref;

  char *command;         /**< External command to start connection   */
  char *cache;           /**< Cache directory.                       */
  char *flags;           /**< Flags directory.                       */

  int use_multiple_connections; /**< Wether to use a separate connection 
				 *   for each folder
				 */
  int max_connections;          /**< If mutlitple connections allowed,
				 *   limit their number to max_connections
				 */

  int subscribed_only;
  XePFolder *folder;
  clist *folders;
  struct mail_list *ep_mail_list;
  struct mail_list *ep_mail_lsub;
};

clist *
a_Mailbox_list_new(void);

clist *
a_Mailbox_list_new_copy(clist *mailboxes);

void
a_Mailbox_list_free(clist *mailboxes);

void
a_Mailbox_list_free_copy(clist *mailboxes);

clist *
a_Mailbox_list_clone(clist *mailboxes);

XePMailbox *
a_Mailbox_new(const char *id);

XePMailbox *
a_Mailbox_new_copy(XePMailbox *mailbox);

void
a_Mailbox_free(XePMailbox *mailbox);

void
a_Mailbox_free_copy(XePMailbox *mailbox);

const char *
a_Mailbox_get_id(XePMailbox *mailbox);

XePMailbox *
a_Mailbox_get_from_uid(long uid);

const char *
a_Mailbox_type_as_string(XePMailboxType type);

XePMailboxType
a_Mailbox_type_from_string(const char *type);

int
a_Mailbox_is_busy(XePMailbox *mailbox);

void
a_Mailbox_disconnect_all(XePMailbox *mailbox);

void
a_Mailbox_disconnect_async(XePMailbox *mailbox,
 			   XePManagerMsgCb user_cb, 
			   void *user_data);
#endif
