/*
 * XetPan: a libEtPan! based Mail User Agent
 * Copyright (C) 2002-2003 Melvin Hadasht
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "x_alloc.h"
#include "logging.h"

#include "server.h"

#define XEP_SERVER_SET_AUTH(server, flag, set) \
  (server->auth_flags = (server->auth_flags & ~flag) | (set ? flag : 0))

#define XEP_SERVER_GET_AUTH(server, flag) \
  ((server->auth_flags & flag) == flag)

enum
  {
    XEP_SERVER_STARTTLS = 1 << 0,
    XEP_SERVER_SSL      = 1 << 1,
    XEP_SERVER_APOP     = 1 << 2
  };

XePServer *
a_Server_new(void)
{
  XePServer *server;

  server = x_alloc(1, XePServer);
  if (server == NULL)
    {
      A_LOGGING_SYSTEM_ERROR("x_alloc: %s", strerror(errno));
    }
  else
    {
      server->host = NULL;
      server->port = 0;
      server->login = NULL;
      server->password = NULL;
      server->auth_flags = 0;
    }

  return server;
}

XePServer *
a_Server_new_copy(XePServer *server)
{
  XePServer *server_copy;

  if (server == NULL)
    return NULL;

  server_copy = a_Server_new();
  if (server_copy)
    {
      server_copy->host = X_STRDUP(server->host);
      server_copy->port = server->port;
      server_copy->login = X_STRDUP(server->login);
      server_copy->password = X_STRDUP(server->password);
      server_copy->auth_flags = server->auth_flags;
    }
  return server_copy;
}

void
a_Server_copy(XePServer *source, XePServer *target)
{
  a_Server_set_host(target, a_Server_get_host(source));
  a_Server_set_port(target, a_Server_get_port(source));
  a_Server_set_login(target, a_Server_get_login(source));
  a_Server_set_password(target, a_Server_get_password(source));
  target->auth_flags = source->auth_flags;
}

void
a_Server_free(XePServer *server)
{
  if (server)
    {
      x_free(server->host);
      x_free(server->login);
      x_free(server->password);
      x_free(server);
    }
}

void
a_Server_set_host(XePServer *server, const char *host)
{
  x_free(server->host);

  if (host)
    {
      server->host = strdup(host);
    }
  else
    server->host = NULL;
}

const char *
a_Server_get_host(XePServer *server)
{
  return server->host;
}

void
a_Server_set_port(XePServer *server, int port)
{
  server->port = port;
}

int
a_Server_get_port(XePServer *server)
{
  return server->port;
}

void
a_Server_set_login(XePServer *server, const char *login)
{
  x_free(server->login);
  if (login)
    server->login = strdup(login);
  else
    server->login = NULL;
}

const char *
a_Server_get_login(XePServer *server)
{
  return server->login;
}

void
a_Server_set_password(XePServer *server, const char *password)
{
  x_free(server->password);
  if (password)
    {
      server->password = strdup(password);
    }
  else
    server->password = NULL;
}

const char *
a_Server_get_password(XePServer *server)
{
  return server->password;
}

void
a_Server_set_starttls(XePServer *server, int use_starttls)
{
  XEP_SERVER_SET_AUTH(server, XEP_SERVER_STARTTLS, use_starttls);
}

int
a_Server_get_starttls(XePServer *server)
{
  return XEP_SERVER_GET_AUTH(server, XEP_SERVER_STARTTLS);
}

void
a_Server_set_ssl(XePServer *server, int use_ssl)
{
  XEP_SERVER_SET_AUTH(server, XEP_SERVER_SSL, use_ssl);
}

int
a_Server_get_ssl(XePServer *server)
{
  return XEP_SERVER_GET_AUTH(server, XEP_SERVER_SSL);
}

void
a_Server_set_apop(XePServer *server, int use_apop)
{
  XEP_SERVER_SET_AUTH(server, XEP_SERVER_APOP, use_apop);
}

int
a_Server_get_apop(XePServer *server)
{
  return XEP_SERVER_GET_AUTH(server, XEP_SERVER_APOP);
}
