/*
 * XetPan: a libEtPan! based Mail User Agent
 * Copyright (C) 2002 Melvin Hadasht
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <gtk/gtk.h>

#include "intl.h"

#include "welcome_dialog.h"

#define SPACING 8

/* Callback functions */
static void
quit_cb(GtkWidget *widget, gpointer data);

static gint
delete_event(GtkWidget *widget, GdkEvent *event, gpointer data);


static void
quit_cb(GtkWidget *widget, gpointer data)
{
  gtk_main_quit();
}

static gint
delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
{
  gtk_main_quit();
  return FALSE;
}

void 
welcome_dialog(XetPan *xetpan, gint compose_attempt)
{
  GtkWidget *window;
  GtkWidget *main_vbox;
  GtkWidget *welcome_vbox;
  GtkWidget *hbox;
  GtkWidget *image;
  GtkWidget *label_vbox;
  GtkWidget *welcome_label;
  GtkWidget *hseparator;
  GtkWidget *help_label;
  GtkWidget *hbuttonbox;
  GtkWidget *quit_button;
  GtkWidget *create_button;

  /* FIXME: remove following debug line */
  printf("Creating welcome window %08x\n", xetpan);
  
  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title(GTK_WINDOW(window), _("XetPan - Welcome"));
  g_signal_connect(G_OBJECT(window), "delete_event", 
		   G_CALLBACK(delete_event), NULL);

  main_vbox = gtk_vbox_new(FALSE, 0);

  welcome_vbox = gtk_vbox_new(FALSE, SPACING);
  
  hbox = gtk_hbox_new(FALSE, SPACING);
  gtk_container_set_border_width(GTK_CONTAINER(hbox), SPACING);


  /*  TODO: icons handling. 
   *
   *  image = gtk_image_new_from_file(XETPAN_APPICON);
   *  gtk_widget_show(image);
   *  gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 0);
   */
 
  label_vbox = gtk_vbox_new(FALSE, SPACING);
  
  welcome_label = gtk_label_new(_("XetPan - Welcome"));
  gtk_label_set_justify(GTK_LABEL(welcome_label), GTK_JUSTIFY_CENTER);
  gtk_widget_show(welcome_label);
  gtk_box_pack_start(GTK_BOX(label_vbox), welcome_label, TRUE, TRUE, 0);

  welcome_label = gtk_label_new(_("Welcome! This is the first time you run "
				  "XetPan.\n\n"
			          "Please create a mail account so "
				  "you will be able to access to "
				  "your mail with XetPan."));
  gtk_label_set_use_markup(GTK_LABEL(welcome_label), TRUE);
  gtk_label_set_line_wrap(GTK_LABEL(welcome_label), TRUE);
  gtk_label_set_justify(GTK_LABEL(welcome_label), GTK_JUSTIFY_LEFT);
  gtk_widget_show(welcome_label);
  gtk_box_pack_start(GTK_BOX(label_vbox), welcome_label, TRUE, TRUE, 0);
  
  hseparator = gtk_hseparator_new();
  gtk_widget_show(hseparator);
  gtk_box_pack_start(GTK_BOX(label_vbox), hseparator, FALSE, FALSE, 0);
  
  help_label = gtk_label_new(_("If you want to create a mail account, click "
  			       "the <b>Create Account</b> button and the "
			       "configuration helper will be started.\n\n"
			       "If you want to quit XetPan, click the "
			       "<b>Quit</b> button."));
  gtk_label_set_use_markup(GTK_LABEL(help_label), TRUE);
  gtk_label_set_line_wrap(GTK_LABEL(help_label), TRUE);
  gtk_widget_show(help_label);
  gtk_box_pack_start(GTK_BOX(label_vbox), help_label, TRUE, TRUE, 0);
  
  gtk_widget_show(label_vbox);
  gtk_box_pack_start(GTK_BOX(hbox), label_vbox, TRUE, TRUE, 0);
  
  gtk_widget_show(hbox);
  gtk_box_pack_start(GTK_BOX(welcome_vbox), hbox, TRUE, TRUE, 0);

  gtk_widget_show(welcome_vbox);
  gtk_box_pack_start(GTK_BOX(main_vbox), welcome_vbox, TRUE, TRUE, 0);

  hseparator = gtk_hseparator_new();
  gtk_widget_show(hseparator);
  gtk_box_pack_start(GTK_BOX(main_vbox), hseparator, FALSE, FALSE, 0);
  
  hbuttonbox = gtk_hbutton_box_new();
  gtk_container_set_border_width(GTK_CONTAINER(hbuttonbox), SPACING);
  gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox), GTK_BUTTONBOX_SPREAD);

  quit_button = gtk_button_new_with_label(_("Quit"));
  gtk_widget_show(quit_button);
  gtk_box_pack_start(GTK_BOX(hbuttonbox), quit_button, TRUE, TRUE, 0);
  g_signal_connect(G_OBJECT(quit_button), "clicked",
		   G_CALLBACK(quit_cb), NULL);

  create_button = gtk_button_new_with_label(_("Create Account"));
  gtk_widget_show(create_button);
  gtk_box_pack_start(GTK_BOX(hbuttonbox), create_button, TRUE, TRUE, 0);


  gtk_widget_show(hbuttonbox);
  gtk_box_pack_start(GTK_BOX(main_vbox), hbuttonbox, FALSE, FALSE, 0);
  
  gtk_widget_show(main_vbox);
  gtk_container_add(GTK_CONTAINER(window), main_vbox);
  
  gtk_widget_show(window);

}

